==> aloe-1.4.2.tar.gz: aloe-1.4.2/modules/gen_crc/src/crc_imp.c <==
/** ALOE headers
 */
#include <phal_sw_api.h>
#include <math.h>
#include <swapi_utils.h>

#include "typetools.h"

#include "itf_types.h"
#include "inputs.h"
#include "outputs.h"
#include "stats.h"

unsigned int poly;
int longblock,longcrc,numblocks;
enum mode_t mode;

int nof_packets,nof_errpkts,nof_err,errorsblk,total;
unsigned int totalpkts,totalerrors;
int t;

char input_bits[INPUT_MAX_DATA*8];

int first=1;

int process_input(int len)
{
    int l,i,n;
    char *wptr;
    int ilongblock,olongblock;

    ilongblock = (mode==ADD)?longblock:longblock+longcrc;
    olongblock = (mode==ADD)?longblock+longcrc:longblock;

    if (len!=typeSizeArray(TYPE_BITSTREAM,numblocks*ilongblock)) {
        Log("CRC: Invalid input length: Mode %s, len=%d, numblocks=%d, longblock=%d\n",(mode==ADD)?"ADD":"CHECK",len,numblocks,longblock);        
    }
    n=1;
    if (mode==CHECK) {
        n=0;
        for (i=0;i<len;i++) {
            n+=input_data[i];
        }
       /* if (!n) {
            Log("CRC: Caution received all ZEROS crc_length=%d len %d\n",longcrc,len);        
        }*/
    }

    bin2char(input_data,input_bits,numblocks*ilongblock);
    wptr=input_bits;

    if (print_bits) {
		printf("%sbits: ", (mode==ADD)?"input":"output");
		for (i=0;i<ilongblock;i++) {
			printf("%d,",input_bits[i]);
		}
		printf("\n");
    }
    for (l=0;l<numblocks;l++) {
        n=icrc(0,wptr,(mode==ADD)?(ilongblock-longcrc):ilongblock,longcrc,poly,mode==ADD);
        if (n==-1) {
            Log("CRC: Error in parameters\n");
            return 0;
        }
        wptr+=longblock+longcrc;
        if (mode==CHECK && n) {
            errorsblk++;
            nof_err++;
            totalerrors++;
            if (totalerrors==1)
                totalpkts=0;
        }

    }

    if (mode==CHECK) {
        total+=len*8;
        nof_packets++;
        nof_errpkts++;
        totalpkts++;
        fer=(float) totalerrors/totalpkts;
    } 

    char2bin(input_bits,output_data,olongblock*numblocks);
    SendItf(0,typeSizeArray(TYPE_BITSTREAM,olongblock*numblocks));

    return 1;
}


int process_control(int len)
{
    longblock=ctrlpkt.long_block;
    longcrc=ctrlpkt.long_crc;
    numblocks=ctrlpkt.num_blocks;
    poly=ctrlpkt.poly;
    mode=ctrlpkt.mode;
    Log("CRC: Mode %s long_blocks=%d num_blocks=%d long_crc=%d\n",(mode==ADD)?"ADD":"CHECK",longblock,numblocks,longcrc);
}

/** Run function.
 * @return 1 if ok, 0 if error
 */
int RunCustom()
{
    if (mode==CHECK) {
        t++;
        if (t==100) {
            Log("CRC:\t total=%d pkts=%d errors=%d blks\n",total,nof_packets,errorsblk);
            t=0;
            nof_packets=0;
            total=0;
            errorsblk=0;
        }
    }
    return 1;
}

int InitCustom()
{
    mode = (mode_i==0)?ADD:CHECK;
    t=0;
    totalpkts=totalerrors=0;
    nof_packets=nof_err=errorsblk=total=0;
    return 1;
}


void ConfigInterfaces(){}

==> aloe-1.4.5.tar.gz: aloe-1.4.5/modules/gen_crc/src/crc_imp.c <==
/** ALOE headers
 */
#include <phal_sw_api.h>
#include <math.h>
#include <swapi_utils.h>

#include "typetools.h"

#include "itf_types.h"
#include "inputs.h"
#include "outputs.h"
#include "stats.h"

unsigned int poly;
int longblock,longcrc,numblocks;
enum mode_t mode;

int nof_packets,nof_errpkts,nof_err,errorsblk,total;
unsigned int totalpkts,totalerrors;
int t;

char input_bits[INPUT_MAX_DATA*8];

int first=1;

int process_input(int len)
{
    int l,i,n;
    char *wptr;
    int ilongblock,olongblock;

    ilongblock = (mode==ADD)?longblock:longblock+longcrc;
    olongblock = (mode==ADD)?longblock+longcrc:longblock;

    if (len!=typeSizeArray(TYPE_BITSTREAM,numblocks*ilongblock)) {
        Log("CRC: Invalid input length: Mode %s, len=%d, numblocks=%d, longblock=%d\n",(mode==ADD)?"ADD":"CHECK",len,numblocks,longblock);        
    }
    n=1;
    if (mode==CHECK) {
        n=0;
        for (i=0;i<len;i++) {
            n+=input_data[i];
        }
       /* if (!n) {
            Log("CRC: Caution received all ZEROS crc_length=%d len %d\n",longcrc,len);        
        }*/
    }

    bin2char(input_data,input_bits,numblocks*ilongblock);
    wptr=input_bits;

    if (print_bits) {
		printf("%sbits: ", (mode==ADD)?"input":"output");
		for (i=0;i<ilongblock;i++) {
			printf("%d,",input_bits[i]);
		}
		printf("\n");
    }
    for (l=0;l<numblocks;l++) {
        n=icrc(0,wptr,ilongblock,longcrc,poly,mode==ADD);
        if (n==-1) {
            Log("CRC: Error in parameters\n");
            return 0;
        }
        wptr+=longblock+longcrc;
        if (mode==CHECK && n) {
            errorsblk++;
            nof_err++;
            totalerrors++;
            if (totalerrors==1)
                totalpkts=0;
        }

    }

    if (mode==CHECK) {
        total+=len*8;
        nof_packets++;
        nof_errpkts++;
        totalpkts++;
        fer=(float) totalerrors/totalpkts;
    } 

    char2bin(input_bits,output_data,olongblock*numblocks);
    SendItf(0,typeSizeArray(TYPE_BITSTREAM,olongblock*numblocks));

    return 1;
}


int process_control(int len)
{
    longblock=ctrlpkt.long_block;
    longcrc=ctrlpkt.long_crc;
    numblocks=ctrlpkt.num_blocks;
    poly=ctrlpkt.poly;
    mode=ctrlpkt.mode;
    Log("CRC: Mode %s long_blocks=%d num_blocks=%d long_crc=%d\n",(mode==ADD)?"ADD":"CHECK",longblock,numblocks,longcrc);
}

/** Run function.
 * @return 1 if ok, 0 if error
 */
int RunCustom()
{
    if (mode==CHECK) {
        t++;
        if (t==100) {
            Log("CRC:\t total=%d pkts=%d errors=%d blks\n",total,nof_packets,errorsblk);
            t=0;
            nof_packets=0;
            total=0;
            errorsblk=0;
        }
    }
    return 1;
}

int InitCustom()
{
    mode = (mode_i==0)?ADD:CHECK;
    t=0;
    totalpkts=totalerrors=0;
    nof_packets=nof_err=errorsblk=total=0;
    return 1;
}


void ConfigInterfaces(){}
